dispMUA.arDispMUAAllocation["q"] =
{
  "qualcomm macintosh classic eudora" : [ "eudora.png" , "http://www.eudora.com/" ] ,
  "qualcomm macos classic eudora" : [ "eudora.png" , "http://www.eudora.com/" ] ,
  "qualcomm windows eudora" : [ "eudora.png" , "http://www.eudora.com/" ] ,
  "qualcomm macos x eudora" : [ "eudora.png" , "http://www.eudora.com/" ] ,
  "qusnetsoft newsreader" : [ "qusnetsoft_newsreader.png" , "http://www.qusnetsoft.ru/" ] ,
  "quality web email" : [ "netwinsite.png" , "http://www.netwinsite.com/webmail/" ] ,
  "quotient q.tools" : [ "quotient_qtools.png" , "http://www.quotientmarketing.com/qtools_defined.aspx" ] ,
  "quickmail pro" : [ "quickmail_pro.png" ] ,
  "qualisite cms" : [ "qualisite_de.png" , "http://www.qualisite.de/" ] ,
  "qa webaccess" : [ "qaconsulting.png" , "http://www.qaconsulting.com.br/" ] ,
  "quickmail" : [ "quickmail.png" ] ,
  "qps.qmail" : [ "python.png" , "http://pypi.python.org/pypi/QPS/" ] ,
  "qqmail" : [ "qqmail.png" ] ,
  "qmail" : [ "qmail.png" , "http://www.qmail.org/" ] ,
}
